==> skill-core-1.12.3-sources.jar: com/ptteng/sca/skill/service/client/UserTaskRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.skill.service.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.skill.service.model.UserTaskRelation;
import com.ptteng.skill.service.service.UserTaskRelationService;

import java.util.List;
import java.util.Map;

public class UserTaskRelationSCAClient implements UserTaskRelationService {

    private UserTaskRelationService userTaskRelationService;

	public UserTaskRelationService getUserTaskRelationService() {
		return userTaskRelationService;
	}
	
	
	public void setUserTaskRelationService(UserTaskRelationService userTaskRelationService) {
		this.userTaskRelationService =userTaskRelationService;
	}
	
	
			   
		@Override
		public Long insert(UserTaskRelation userTaskRelation)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.insert(userTaskRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<UserTaskRelation> insertList(List<UserTaskRelation> userTaskRelationList)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.insertList(userTaskRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserTaskRelation userTaskRelation)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.update(userTaskRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserTaskRelation> userTaskRelationList)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.updateList(userTaskRelationList);
		          
		
		}	
		  
    	   
		@Override
		public UserTaskRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserTaskRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getUserTaskRelationIdByTidAndUid(Long tid,Long uid)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.getUserTaskRelationIdByTidAndUid(tid,uid);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserTaskRelationIdsByUidAndOid(Long uid,Long oid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.getUserTaskRelationIdsByUidAndOid(uid,oid,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserTaskRelationIdsByUidAndOid(Long uid,Long oid)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.countUserTaskRelationIdsByUidAndOid(uid,oid);
	
	
	}
	
		
	
		@Override
	public List<Long> getUserTaskRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userTaskRelationService.getUserTaskRelationIds(start, limit);
	}

	@Override
	public Integer countUserTaskRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userTaskRelationService.countUserTaskRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userTaskRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userTaskRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userTaskRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userTaskRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}

==> skill-core-12.0.0-sources.jar: com/ptteng/sca/skill/service/client/UserTaskRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.skill.service.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.skill.service.model.UserTaskRelation;
import com.ptteng.skill.service.service.UserTaskRelationService;

import java.util.List;
import java.util.Map;

public class UserTaskRelationSCAClient implements UserTaskRelationService {

    private UserTaskRelationService userTaskRelationService;

	public UserTaskRelationService getUserTaskRelationService() {
		return userTaskRelationService;
	}
	
	
	public void setUserTaskRelationService(UserTaskRelationService userTaskRelationService) {
		this.userTaskRelationService =userTaskRelationService;
	}
	
	
			   
		@Override
		public Long insert(UserTaskRelation userTaskRelation)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.insert(userTaskRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<UserTaskRelation> insertList(List<UserTaskRelation> userTaskRelationList)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.insertList(userTaskRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserTaskRelation userTaskRelation)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.update(userTaskRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserTaskRelation> userTaskRelationList)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.updateList(userTaskRelationList);
		          
		
		}	
		  
    	   
		@Override
		public UserTaskRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserTaskRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getUserTaskRelationIdByTidAndUid(Long tid,Long uid)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.getUserTaskRelationIdByTidAndUid(tid,uid);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserTaskRelationIdsByUidAndOid(Long uid,Long oid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.getUserTaskRelationIdsByUidAndOid(uid,oid,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserTaskRelationIdsByUidAndOid(Long uid,Long oid)throws ServiceException, ServiceDaoException{
		
		return userTaskRelationService.countUserTaskRelationIdsByUidAndOid(uid,oid);
	
	
	}
	
		
	
		@Override
	public List<Long> getUserTaskRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userTaskRelationService.getUserTaskRelationIds(start, limit);
	}

	@Override
	public Integer countUserTaskRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userTaskRelationService.countUserTaskRelationIds();
	}

	@Override
	public List<Long> getUserTaskRelationIdsByUid(Long uid,Integer start, Integer limit) throws ServiceException, ServiceDaoException {
		return userTaskRelationService.getUserTaskRelationIdsByUid(uid,start,limit);
	}


	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userTaskRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userTaskRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userTaskRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userTaskRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}
